==> ejc-report-impl-3.0.0-20201112.113128-24-sources.jar: com/ejianc/foundation/report/controller/param/GridHeader.java <==
package com.ejianc.foundation.report.controller.param;

import java.io.Serializable;

/**
 * 表头属性
 * 
 * @author guoming
 *
 */
public class GridHeader implements Serializable {

	private static final long serialVersionUID = -2043890697260188111L;

	private String id;

	private String code;

	private String name;

	private Boolean visible;

	private Integer showOrder;

	private String type;

	private Boolean innerFilter;

	private Long parentId;

	//数据格式话js函数
	private String formatter;

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public String getCode() {
		return code;
	}

	public void setCode(String code) {
		this.code = code;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public Boolean getVisible() {
		return visible;
	}

	public void setVisible(Boolean visible) {
		this.visible = visible;
	}

	public Integer getShowOrder() {
		return showOrder;
	}

	public void setShowOrder(Integer showOrder) {
		this.showOrder = showOrder;
	}

	public String getType() {
		return type;
	}

	public void setType(String type) {
		this.type = type;
	}

	public Boolean getInnerFilter() {
		return innerFilter;
	}

	public void setInnerFilter(Boolean innerFilter) {
		this.innerFilter = innerFilter;
	}

	public Long getParentId() {
		return parentId;
	}

	public void setParentId(Long parentId) {
		this.parentId = parentId;
	}

	public String getFormatter() {
		return formatter;
	}

	public void setFormatter(String formatter) {
		this.formatter = formatter;
	}
}

==> ejc-report-impl-3.0.0-20201123.120816-42-sources.jar: com/ejianc/foundation/report/controller/param/GridHeader.java <==
package com.ejianc.foundation.report.controller.param;

import java.io.Serializable;

/**
 * 表头属性
 * 
 * @author guoming
 *
 */
public class GridHeader implements Serializable {

	private static final long serialVersionUID = -2043890697260188111L;

	private String id;

	private String code;

	private String name;

	private Boolean visible;

	private Integer showOrder;

	private String type;

	private Boolean innerFilter;

	private Long parentId;

	//数据格式话js函数
	private String formatter;

	//导出格式化
	private String exportFormat;

	//是否开启数据汇总
	private Boolean enableSummarize;

	//列对齐方式
	private String alignType;

	public String getAlignType() {
		return alignType;
	}

	public void setAlignType(String alignType) {
		this.alignType = alignType;
	}

	public String getExportFormat() {
		return exportFormat;
	}

	public void setExportFormat(String exportFormat) {
		this.exportFormat = exportFormat;
	}

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public String getCode() {
		return code;
	}

	public void setCode(String code) {
		this.code = code;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public Boolean getVisible() {
		return visible;
	}

	public void setVisible(Boolean visible) {
		this.visible = visible;
	}

	public Integer getShowOrder() {
		return showOrder;
	}

	public void setShowOrder(Integer showOrder) {
		this.showOrder = showOrder;
	}

	public String getType() {
		return type;
	}

	public void setType(String type) {
		this.type = type;
	}

	public Boolean getInnerFilter() {
		return innerFilter;
	}

	public void setInnerFilter(Boolean innerFilter) {
		this.innerFilter = innerFilter;
	}

	public Long getParentId() {
		return parentId;
	}

	public void setParentId(Long parentId) {
		this.parentId = parentId;
	}

	public String getFormatter() {
		return formatter;
	}

	public void setFormatter(String formatter) {
		this.formatter = formatter;
	}

	public Boolean getEnableSummarize() {
		return enableSummarize;
	}

	public void setEnableSummarize(Boolean enableSummarize) {
		this.enableSummarize = enableSummarize;
	}
}
